@@ -4,6 +4,8 @@ Module for IO relevant functions
 import sys
 import os
 import json
+sys.path.insert(0, os.path.abspath('./dmitio/'))
+from .arguments import arguments
 
 def read_json(infile):
     """Reads data from a json file
